#[repr(u8)]pub enum CommandType {
EndOfDocument = 0,
FillPolygon = 1,
FillRectangles = 2,
FillPath = 3,
DrawLines = 4,
DrawLineLoop = 5,
DrawLineStrip = 6,
DrawLinePath = 7,
OutlineFillPolygon = 8,
OutlineFillRectangles = 9,
OutlineFillPath = 10,
TextHint = 11,
}Expand description
The next draw command.
Variants
EndOfDocument = 0
This command determines the end of file.
FillPolygon = 1
This command fills an N-gon.
FillRectangles = 2
This command fills a set of rectangles.
FillPath = 3
This command fills a free-form path.
DrawLines = 4
This command draws a set of lines.
DrawLineLoop = 5
This command draws the outline of a polygon.
DrawLineStrip = 6
This command draws a list of end-to-end lines.
DrawLinePath = 7
This command draws a free-form path.
OutlineFillPolygon = 8
This command draws a filled polygon with an outline.
OutlineFillRectangles = 9
This command draws several filled rectangles with an outline.
OutlineFillPath = 10
This command combines the fill and draw line path command into one.
TextHint = 11
This command defines the contents and glyph location for text.