pub enum DrawCommand {
FillPolygon(FillPolygonData),
FillRectangles(FillRectanglesData),
FillPath(FillPathData),
DrawLines(DrawLinesData),
DrawLineLoop(DrawLineLoopData),
DrawLineStrip(DrawLineStripData),
DrawLinePath(DrawLinePathData),
OutlineFillPolygon(OutlineFillPolygonData),
OutlineFillRectangles(OutlineFillRectanglesData),
OutlineFillPath(OutlineFillPathData),
TextHint(TextHintData),
}Variants
FillPolygon(FillPolygonData)
This command fills an N-gon.
FillRectangles(FillRectanglesData)
This command fills a set of rectangles.
FillPath(FillPathData)
This command fills a free-form path.
DrawLines(DrawLinesData)
This command draws a set of lines.
DrawLineLoop(DrawLineLoopData)
This command draws the outline of a polygon.
DrawLineStrip(DrawLineStripData)
This command draws a list of end-to-end lines.
DrawLinePath(DrawLinePathData)
This command draws a free-form path.
OutlineFillPolygon(OutlineFillPolygonData)
This command draws a filled polygon with an outline.
OutlineFillRectangles(OutlineFillRectanglesData)
This command draws several filled rectangles with an outline.
OutlineFillPath(OutlineFillPathData)
This command combines the fill and draw line path command into one.
TextHint(TextHintData)
This command only provides metadata for accessibility or text selection tools for the position and content of text. A renderer can safely ignore this command since it must not have any effect on the resulting graphic.