#[repr(u8)]pub enum StyleType {
Flat = 0,
Linear = 1,
Radial = 2,
}Variants
Flat = 0
Colored The shape is uniformly colored with a single color.
Linear = 1
Gradient The shape is colored with a linear gradient.
Radial = 2
Gradient The shape is colored with a radial gradient.