pub struct TextHintData {
pub center: Point,
pub rotation: Unit,
pub height: Unit,
pub text: String,
pub glyph_length: u64,
pub glyph_offset: Vec<(Unit, Unit)>,
}Fields
center: PointThe center of the descender line for the defined text.
rotation: UnitThe amount of degrees the text is rotated.
height: UnitThe font size or distance from the ascender line to the descender line for the text.
text: Stringglyph_length: u64The number of glyphs within the text.
glyph_offset: Vec<(Unit, Unit)>The start and end offset on the descender line from the center for each glyph