pub struct TinyVgHeader {
pub magic: [u8; 2],
pub version: u8,
pub scale: u8,
pub color_encoding: ColorEncoding,
pub coordinate_range: CoordinateRange,
pub width: u32,
pub height: u32,
pub color_count: u64,
}Fields
magic: [u8; 2]https://en.wikipedia.org/wiki/File_format#Magic_number
version: u8The TinyVG version.
scale: u8Defines the number of fraction bits in a Unit value.
color_encoding: ColorEncodingDefines the type of color information that is used in the color table.
coordinate_range: CoordinateRangeDefines the number of total bits in a Unit value and thus the overall precision of the file.
width: u32Encodes the maximum width of the output file in display units. A value of 0 indicates that the image has the maximum possible width.
height: u32Encodes the maximum height of the output file in display units. A value of 0 indicates that the image has the maximum possible height.
color_count: u64The number of colors in the color table.