Enum ColorEncoding

#[repr(u8)]
pub enum ColorEncoding { Rgba8888 = 0, Rgb565 = 1, RgbaF32 = 2, Custom = 3, }

Variants



Rgba8888 = 0

Each color is a 4-tuple (red, green, blue, alpha) of bytes with the color channels encoded in sRGB and the alpha as linear alpha.



Rgb565 = 1

Each color is encoded as a 3-tuple (red, green, blue) with 16 bit per color. While red and blue both use 5 bit, the green channel uses 6 bit. red uses bit range 0…4, green bits 5…10 and blue bits 11…15. This color also uses the sRGB color space.



RgbaF32 = 2

Each color is a 4-tuple (red, green ,blue, alpha) of binary32 IEEE 754 floating point value with the color channels encoded in scRGB and the alpha as linear alpha. A color value of 1.0 is full intensity, while a value of 0.0 is zero intensity.



Custom = 3

The custom color encoding is defined undefined. The information how these colors are encoded must be implemented via external means.